@@ -36,7 +36,7 @@ PERFORMANCE OF THIS SOFTWARE.
 #include "Xlcint.h"
 #include "Ximint.h"
 
-Private void
+static void
 _XimLocalUnSetFocus(
     XIC	 xic)
 {
@@ -49,7 +49,7 @@ _XimLocalUnSetFocus(
     return;
 }
 
-Private void
+static void
 _XimLocalDestroyIC(
     XIC	 xic)
 {
@@ -61,14 +61,20 @@ _XimLocalDestroyIC(
     if (ic->core.focus_window)
 	_XUnregisterFilter(ic->core.im->core.display,
 			ic->core.focus_window, _XimLocalFilter, (XPointer)ic);
-    if(ic->private.local.ic_resources) {
-	Xfree(ic->private.local.ic_resources);
-	ic->private.local.ic_resources = NULL;
-    }
+
+    Xfree(ic->private.local.ic_resources);
+    ic->private.local.ic_resources = NULL;
+
+    Xfree(ic->core.res_name);
+    ic->core.res_name=NULL;
+
+    Xfree(ic->core.res_class);
+    ic->core.res_class = NULL;
+
     return;
 }
 
-Private void
+static void
 _XimLocalSetFocus(
     XIC	 xic)
 {
@@ -90,7 +96,7 @@ _XimLocalSetFocus(
     return;
 }
 
-Private void
+static void
 _XimLocalReset(
     XIC	 xic)
 {
@@ -102,7 +108,7 @@ _XimLocalReset(
     ic->private.local.brl_committed  = 0;
 }
 
-Private char *
+static char *
 _XimLocalMbReset(
     XIC	 xic)
 {
@@ -110,7 +116,7 @@ _XimLocalMbReset(
     return (char *)NULL;
 }
 
-Private wchar_t *
+static wchar_t *
 _XimLocalWcReset(
     XIC	 xic)
 {
@@ -118,7 +124,7 @@ _XimLocalWcReset(
     return (wchar_t *)NULL;
 }
 
-Private XICMethodsRec Local_ic_methods = {
+static XICMethodsRec Local_ic_methods = {
     _XimLocalDestroyIC, 	/* destroy */
     _XimLocalSetFocus,  	/* set_focus */
     _XimLocalUnSetFocus,	/* unset_focus */
@@ -132,21 +138,21 @@ Private XICMethodsRec Local_ic_methods = {
     _XimLocalUtf8LookupString	/* utf8_lookup_string */
 };
 
-Public XIC
+XIC
 _XimLocalCreateIC(
     XIM			 im,
     XIMArg		*values)
 {
     Xic			 ic;
-    XimDefICValues	 ic_values;
+    XimDefICValues	 ic_values={ 0 };
     XIMResourceList	 res;
     unsigned int	 num;
     int			 len;
 
-    if((ic = (Xic)Xmalloc(sizeof(XicRec))) == (Xic)NULL) {
+    ic = Xcalloc(1, sizeof(XicRec));
+    if( ic  == (Xic)NULL) {
 	return ((XIC)NULL);
     }
-    bzero((char *)ic, sizeof(XicRec));
 
     ic->methods = &Local_ic_methods;
     ic->core.im = im;
@@ -159,15 +165,15 @@ _XimLocalCreateIC(
 
     num = im->core.ic_num_resources;
     len = sizeof(XIMResource) * num;
-    if((res = (XIMResourceList)Xmalloc(len)) == (XIMResourceList)NULL) {
+    res = Xmalloc(len);
+    if( res  == (XIMResourceList)NULL) {
 	goto Set_Error;
     }
     (void)memcpy((char *)res, (char *)im->core.ic_resources, len);
     ic->private.local.ic_resources     = res;
     ic->private.local.ic_num_resources = num;
 
-    bzero((char *)&ic_values, sizeof(XimDefICValues));
-    if(_XimCheckLocalInputStyle(ic, (XPointer)&ic_values, values,
+     if(_XimCheckLocalInputStyle(ic, (XPointer)&ic_values, values,
 				 im->core.styles, res, num) == False) {
 	goto Set_Error;
     }
@@ -191,10 +197,10 @@ _XimLocalCreateIC(
     return((XIC)ic);
 
 Set_Error :
-    if (ic->private.local.ic_resources) {
-	Xfree(ic->private.local.ic_resources);
-	ic->private.local.ic_resources = NULL;
-    }
+
+    Xfree(ic->private.local.ic_resources);
+     ic->private.local.ic_resources = NULL;
+
     Xfree(ic);
     return((XIC)NULL);
 }
