@@ -511,7 +511,7 @@ LINEAR_RGB_InitSCCData(
 	    *pValue++ = (long)_XcmsGetElement(format_return, &pChar,
 		    &nitems) / (XcmsFloat)XDCCC_NUMBER;
 	}
-	Xfree ((char *)property_return);
+	Xfree (property_return);
 	pPerScrnInfo->screenWhitePt.spec.CIEXYZ.X =
 		pScreenData->RGBtoXYZmatrix[0][0] +
 		pScreenData->RGBtoXYZmatrix[0][1] +
@@ -653,7 +653,7 @@ LINEAR_RGB_InitSCCData(
 	     */
 	    if (!(pScreenData = (LINEAR_RGB_SCCData *)
 			      Xcalloc (1, sizeof(LINEAR_RGB_SCCData)))) {
-		return(XcmsFailure);
+		goto Free_property_return;
 	    }
 	    /* copy matrices */
 	    memcpy((char *)pScreenData, (char *)pScreenDefaultData,
@@ -662,8 +662,8 @@ LINEAR_RGB_InitSCCData(
 	    /* Create, initialize, and add map */
 	    if (!(pNewMap = (XcmsIntensityMap *)
 			      Xcalloc (1, sizeof(XcmsIntensityMap)))) {
-		Xfree((char *)pScreenData);
-		return(XcmsFailure);
+		Xfree(pScreenData);
+		goto Free_property_return;
 	    }
 	    pNewMap->visualID = visualID;
 	    pNewMap->screenData = (XPointer)pScreenData;
@@ -782,7 +782,7 @@ LINEAR_RGB_InitSCCData(
 #endif /* ALLDEBUG */
     }
 
-    Xfree ((char *)property_return);
+    Xfree (property_return);
 
     /* Free the old memory and use the new structure created. */
     LINEAR_RGB_FreeSCCData(pPerScrnInfo->screenData);
@@ -795,29 +795,29 @@ LINEAR_RGB_InitSCCData(
 
     return(XcmsSuccess);
 
-FreeBlueTblElements:
-    Xfree((char *)pScreenData->pBlueTbl->pBase);
+FreeBlueTblElements: _X_UNUSED
+    Xfree(pScreenData->pBlueTbl->pBase);
 
 FreeBlueTbl:
-    Xfree((char *)pScreenData->pBlueTbl);
+    Xfree(pScreenData->pBlueTbl);
 
 FreeGreenTblElements:
-    Xfree((char *)pScreenData->pBlueTbl->pBase);
+    Xfree(pScreenData->pGreenTbl->pBase);
 
 FreeGreenTbl:
-    Xfree((char *)pScreenData->pGreenTbl);
+    Xfree(pScreenData->pGreenTbl);
 
 FreeRedTblElements:
-    Xfree((char *)pScreenData->pRedTbl->pBase);
+    Xfree(pScreenData->pRedTbl->pBase);
 
 FreeRedTbl:
-    Xfree((char *)pScreenData->pRedTbl);
+    Xfree(pScreenData->pRedTbl);
 
 Free_property_return:
-    Xfree ((char *)property_return);
+    Xfree (property_return);
 
 FreeSCCData:
-    Xfree((char *)pScreenData);
+    Xfree(pScreenDefaultData);
     pPerScrnInfo->state = XcmsInitNone;
     return(XcmsFailure);
 }
@@ -849,30 +849,30 @@ LINEAR_RGB_FreeSCCData(
 		if (pScreenData->pRedTbl->pBase !=
 		    pScreenData->pGreenTbl->pBase) {
 		    if (pScreenData->pGreenTbl->pBase) {
-			Xfree ((char *)pScreenData->pGreenTbl->pBase);
+			Xfree (pScreenData->pGreenTbl->pBase);
 		    }
 		}
 		if (pScreenData->pGreenTbl != pScreenData->pRedTbl) {
-		    Xfree ((char *)pScreenData->pGreenTbl);
+		    Xfree (pScreenData->pGreenTbl);
 		}
 	    }
 	    if (pScreenData->pBlueTbl) {
 		if (pScreenData->pRedTbl->pBase !=
 		    pScreenData->pBlueTbl->pBase) {
 		    if (pScreenData->pBlueTbl->pBase) {
-			Xfree ((char *)pScreenData->pBlueTbl->pBase);
+			Xfree (pScreenData->pBlueTbl->pBase);
 		    }
 		}
 		if (pScreenData->pBlueTbl != pScreenData->pRedTbl) {
-		    Xfree ((char *)pScreenData->pBlueTbl);
+		    Xfree (pScreenData->pBlueTbl);
 		}
 	    }
 	    if (pScreenData->pRedTbl->pBase) {
-		Xfree ((char *)pScreenData->pRedTbl->pBase);
+		Xfree (pScreenData->pRedTbl->pBase);
 	    }
-	    Xfree ((char *)pScreenData->pRedTbl);
+	    Xfree (pScreenData->pRedTbl);
 	}
-	Xfree ((char *)pScreenData);
+	Xfree (pScreenData);
     }
 }
 
@@ -966,7 +966,7 @@ _XcmsGetTableType1(
  *
  */
 {
-    int count;
+    unsigned int count;
     unsigned int max_index;
     IntensityRec *pIRec;
 
@@ -1178,7 +1178,7 @@ _XcmsTableSearch(
 
 /*
  *	DESCRIPTION
- *		A binary search through the specificied table.
+ *		A binary search through the specified table.
  *
  *	RETURNS
  *		Returns 0 if failed; otherwise non-zero.
@@ -1293,7 +1293,7 @@ XcmsLRGB_RGB_ParseString(
 	 * Attempt to parse the value portion.
 	 */
 	spec++;
-	n = strlen(spec);
+	n = (int)strlen(spec);
 	if (n != 3 && n != 6 && n != 9 && n != 12) {
 	    return(XcmsFailure);
 	}
@@ -1337,7 +1337,7 @@ XcmsLRGB_RGB_ParseString(
 	/*
 	 * Check for proper prefix.
 	 */
-	if (strncmp(spec, _XcmsRGB_prefix, n) != 0) {
+	if (strncmp(spec, _XcmsRGB_prefix, (size_t)n) != 0) {
 	    return(XcmsFailure);
 	}
 
@@ -1405,13 +1405,13 @@ XcmsLRGB_RGBi_ParseString(
  *		0 if failed, non-zero otherwise.
  */
 {
-    int n;
+    size_t n;
     char *pchar;
 
     if ((pchar = strchr(spec, ':')) == NULL) {
 	return(XcmsFailure);
     }
-    n = (int)(pchar - spec);
+    n = (size_t)(pchar - spec);
 
     /*
      * Check for proper prefix.
