@@ -24,12 +24,9 @@ THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 ********************************************************/
 
-#ifdef DEBUG
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#include <stdio.h>
-#endif
 
 #define NEED_MAP_READERS
 #include "Xlibint.h"
